package BPAN;
use 5.006001;
use strict;
use warnings;
$BPAN::VERSION = '0.01';

1;

=head1 NAME

BPAN - Be Patient And Nonesuch

=head1 SYNOPSIS

    use BPAN;

=head1 DESCRIPTION

BPAN is the new CPAN. Stay tuned...

=head1 AUTHOR

Ingy döt Net

=head1 COPYRIGHT

Copyright (c) 2007. Ingy döt Net. All rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html

=cut
